"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Paper = exports.max = exports.min = exports.exact = exports.breakpoints = undefined;

var _templateObject = _taggedTemplateLiteral(["\n\t\t@media (min-width: ", "em) and (max-width: ", "em) {\n\t\t\t", "\n\t\t}\n\t"], ["\n\t\t@media (min-width: ", "em) and (max-width: ", "em) {\n\t\t\t", "\n\t\t}\n\t"]),
    _templateObject2 = _taggedTemplateLiteral(["\n\t\t@media (min-width: ", "em) {\n\t\t\t", "\n\t\t}\n\t"], ["\n\t\t@media (min-width: ", "em) {\n\t\t\t", "\n\t\t}\n\t"]),
    _templateObject3 = _taggedTemplateLiteral(["\n\t\t@media (max-width: ", "em) {\n\t\t\t", "\n\t\t}\n\t"], ["\n\t\t@media (max-width: ", "em) {\n\t\t\t", "\n\t\t}\n\t"]),
    _templateObject4 = _taggedTemplateLiteral(["\n        font-family: Arial, sans-serif;\n        letter-spacing: 0.005em;\n        line-height: ", "em;\n        font-weight: 700;\n        margin: 0;\n        /* in some cases this vv doesn't work and causes garbage CSS */\n        .fonts-loaded-headers & {\n          ", ";\n        }\n      "], ["\n        font-family: Arial, sans-serif;\n        letter-spacing: 0.005em;\n        line-height: ", "em;\n        font-weight: 700;\n        margin: 0;\n        /* in some cases this vv doesn't work and causes garbage CSS */\n        .fonts-loaded-headers & {\n          ", ";\n        }\n      "]),
    _templateObject5 = _taggedTemplateLiteral(["\n        font-family: ", ", Arial, sans-serif;\n        letter-spacing: 0.025em;\n        font-weight: 600;\n      "], ["\n        font-family: ", ", Arial, sans-serif;\n        letter-spacing: 0.025em;\n        font-weight: 600;\n      "]),
    _templateObject6 = _taggedTemplateLiteral(["\n        font-family: Georgia, serif;\n        letter-spacing: 0.05em;\n        line-height: ", "em;\n        .fonts-loaded & {\n          ", ";\n        }\n      "], ["\n        font-family: Georgia, serif;\n        letter-spacing: 0.05em;\n        line-height: ", "em;\n        .fonts-loaded & {\n          ", ";\n        }\n      "]),
    _templateObject7 = _taggedTemplateLiteral(["\n        font-family: ", ", Georgia, serif;\n        letter-spacing: 0.025em;\n      "], ["\n        font-family: ", ", Georgia, serif;\n        letter-spacing: 0.025em;\n      "]),
    _templateObject8 = _taggedTemplateLiteral(["\n        ", " ", " ", " ", ";\n      "], ["\n        ", " ", " ", " ", ";\n      "]),
    _templateObject9 = _taggedTemplateLiteral(["font-size: \t", "px;"], ["font-size: \t", "px;"]),
    _templateObject10 = _taggedTemplateLiteral(["font-size:\t", "px;"], ["font-size:\t", "px;"]);

var _styledComponents = require("styled-components");

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); } // styles


// css
var breakpoints = exports.breakpoints = {
  // base: pixels
  xxl: [1601, 160000000],
  xl: [1081, 1600],
  l: [751, 1080],
  m: [521, 750],
  s: [321, 520],
  xs: [0, 320]

  // px to em
};var pxEm = function pxEm(px) {
  return px / 16;
};

// print media queries for exact range:
var exact = exports.exact = Object.keys(breakpoints).reduce(function (accumulator, label) {
  accumulator[label] = function () {
    return (0, _styledComponents.css)(_templateObject, pxEm(breakpoints[label][0]), pxEm(breakpoints[label][1]), _styledComponents.css.apply(undefined, arguments));
  };
  return accumulator;
}, {});

// print media queries with no max value:
var min = exports.min = Object.keys(breakpoints).reduce(function (accumulator, label) {
  accumulator[label] = function () {
    return (0, _styledComponents.css)(_templateObject2, pxEm(breakpoints[label][0]), _styledComponents.css.apply(undefined, arguments));
  };
  return accumulator;
}, {});

// print media queries with no min value:
var max = exports.max = Object.keys(breakpoints).reduce(function (accumulator, label) {
  accumulator[label] = function () {
    return (0, _styledComponents.css)(_templateObject3, pxEm(breakpoints[label][1]), _styledComponents.css.apply(undefined, arguments));
  };
  return accumulator;
}, {});

var Paper = exports.Paper = {
  color: {
    brand: "#ed236e",
    foreground: "#2c2c2c",
    background: "#fff",
    highlight: "#fff200",
    alpha: {
      foreground: function foreground(alpha) {
        return "rgba(44, 44, 44, " + alpha + ")";
      },
      brand: function brand(alpha) {
        return "rgba(237, 35, 110, " + alpha + ")";
      },
      highlight: function highlight(alpha) {
        return "rgba(255, 242, 0, " + alpha + ")";
      }
    }
  },
  opacity: {
    most: 0.85,
    half: 0.5,
    least: 0.125
  },
  effects: {
    borderRadius: {
      // base: multiplier
      small: 0.25,
      med: 0.5
    }
  },
  typography: {
    font: {
      sans: "'Exo 2'",
      serif: "Lora"
    },
    title: {
      auto: (0, _styledComponents.css)(_templateObject4, function () {
        return Paper.typography.title.lineHeight;
      }, function () {
        return Paper.typography.title.fontsLoaded;
      }),
      fontsLoaded: (0, _styledComponents.css)(_templateObject5, function () {
        return Paper.typography.font.sans;
      }),
      lineHeight: 1.15 // base: multiplier
    },
    text: {
      auto: (0, _styledComponents.css)(_templateObject6, function () {
        return Paper.typography.text.lineHeight;
      }, function () {
        return Paper.typography.text.fontsLoaded;
      }),
      fontsLoaded: (0, _styledComponents.css)(_templateObject7, function () {
        return Paper.typography.font.serif;
      }),
      lineHeight: 1.75 // base: multiplier
    }
  },
  size: {
    breakpoint: {
      exact: exact,
      min: min,
      max: max,
      stops: {
        min: breakpoints.xs[1],
        max: breakpoints.xl[1]
      }
    },
    font: {
      // base: pixels
      l: 23,
      m: 20,
      s: 18,
      xs: 17,
      make: {
        // base: multiplier
        larger: 3,
        normal: 1,
        smaller: 0.85,
        tiny: 0.65
      },
      // automatically set font size based on screen size; should be at the top of most components' css
      auto: (0, _styledComponents.css)(_templateObject8, min.m(_templateObject9, function () {
        return Paper.size.font.m;
      }), max.s(_templateObject9, function () {
        return Paper.size.font.s;
      }), max.xs(_templateObject9, function () {
        return Paper.size.font.xs;
      }), min.xxl(_templateObject10, function () {
        return Paper.size.font.l;
      }))
    },
    block: {
      column: {
        maxwidth: {
          // base: pixels
          m: 750,
          l: 820
        },
        safety: 1.5 // base: multiplier
      },
      spacing: 1, // base: multiplier
      border: 8, // base: pixels
      minFigureWIdth: 450 // base: pixels
    }
  },
  layer: {
    overlay: 40,
    card: 30,
    nav: 20,
    up: 10,
    tuck: -1
  },
  elements: {
    thickBorder: function thickBorder() {
      return Paper.size.block.border + "px solid " + Paper.color.foreground;
    }
  }
};